@@ -403,7 +403,8 @@ class Model(BaseModel):
             )
             if result:
                 fields = cls.get_fields(cls)
-                return cls(**{k:v for k,v in result.items() if k in fields})
+                result = {k:v for k,v in dict(result).items() if k in fields}
+                return cls(**result)
             else:
                 raise NoDataFound(
                     message=f"Data not found over {cls.Meta.name!s}"
